@@ -224,9 +224,9 @@ class TTTH_Analyzer:
         max_class = class_count.max()
         min_class = class_count.min()
         ratio_of_classes = max_class/min_class
-        self.logger(f'Ratio of 2 class is {round(ratio_of_classes, 2)}')
+        self.logger.info(f'Ratio of 2 class is {round(ratio_of_classes, 2)}')
         if ratio_of_classes >=2:
-            self.logger(f'You should consider to handle imbalance')
+            self.logger.info(f'You should consider to handle imbalance')
 
     def check_outlier_of_numerical_variable(self, numerical_variable, df):
         """
